Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(160)

Unified Diff: components/image_fetcher/image_fetcher_delegate.h

Issue 1974013002: Replace SkBitmap with gfx::Image in the ImageFetcher API. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Sync again Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/image_fetcher/image_fetcher.h ('k') | components/ntp_snippets/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/image_fetcher/image_fetcher_delegate.h
diff --git a/components/image_fetcher/image_fetcher_delegate.h b/components/image_fetcher/image_fetcher_delegate.h
index 0256516ef968ea025e37861d04eb6fe2c9512159..dbc9dd65dff41fae27ad5a22c98c634bd54dd62d 100644
--- a/components/image_fetcher/image_fetcher_delegate.h
+++ b/components/image_fetcher/image_fetcher_delegate.h
@@ -8,7 +8,10 @@
#include "base/macros.h"
class GURL;
-class SkBitmap;
+
+namespace gfx {
+class Image;
+}
namespace image_fetcher {
@@ -17,9 +20,9 @@ class ImageFetcherDelegate {
ImageFetcherDelegate() {}
// Called when an image was fetched. |url| represents the website for which
- // the image was fetched. |bitmap| stores image data owned by the caller, and
- // can be nullptr.
- virtual void OnImageFetched(const GURL& url, const SkBitmap* bitmap) = 0;
+ // the image was fetched. |image| stores image data owned by the caller, and
+ // can be an empty gfx::Image.
+ virtual void OnImageFetched(const GURL& url, const gfx::Image& image) = 0;
protected:
virtual ~ImageFetcherDelegate() {}
« no previous file with comments | « components/image_fetcher/image_fetcher.h ('k') | components/ntp_snippets/BUILD.gn » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698